AnalysisConfig class

Constructors

AnalysisConfig({double? maxFramesPerSecond, bool autoStart = true, AndroidAnalysisOptions androidOptions = const AndroidAnalysisOptions.nv21(width: 500), CupertinoAnalysisOptions cupertinoOptions = const CupertinoAnalysisOptions.bgra8888()})

Properties

androidOptions → AndroidAnalysisOptions
Android specific options for image analysis.
final
autoStart → bool
When set to true, image analysis starts automatically. Otherwise, you will have to start it manually using AnalysisController.start()
final
cupertinoOptions → CupertinoAnalysisOptions
iOS specific options for image analysis.
final
hashCode → int
The hash code for this object.
no setterinherited
maxFramesPerSecond → double?
This is used to improve performance on low performance devices. It will skip frames if the camera is producing more than the specified.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited