AnalysisController class

Constructors

AnalysisController.fromPlugin({OnImageForAnalysis? onImageListener, required AnalysisConfig? conf})
factory

Properties

conf → AnalysisConfig
final
enabled → dynamic
no setter
hashCode → int
The hash code for this object.
no setterinherited
imageSubscription ↔ StreamSubscription?
getter/setter pair
onImageListener → OnImageForAnalysis?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setup() → Future<void>
start() → Future<bool>
stop() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited