AnalysisImage class abstract

Available extensions

Constructors

AnalysisImage({required int height, required int width, required InputAnalysisImageFormat format, required InputAnalysisImageRotation rotation})
const
AnalysisImage.from(Map<String, dynamic> map)
factory

Properties

croppedSize → Size
Cropped size of the analysis image corresponding to what is seen on the preview.
no setter
format → InputAnalysisImageFormat
The format of the image.
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
The height of the image in pixels.
final
inputImageFormat → InputImageFormat

Available on AnalysisImage, provided by the MLKitUtils extension

no setter
inputImageRotation → InputImageRotation

Available on AnalysisImage, provided by the MLKitUtils extension

no setter
rotation → InputAnalysisImageRotation
The rotation of the image.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size
Full size of the analysis image.
no setter
width → int
The width of the image in pixels.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toInputImage() → InputImage

Available on AnalysisImage, provided by the MLKitUtils extension

toString() → String
A string representation of this object.
inherited
when<T>({T nv21(Nv21Image image)?, T bgra8888(Bgra8888Image image)?, T jpeg(JpegImage image)?, T yuv420(Yuv420Image image)?}) → T?
Helper function to decide what to do depending on the AnalysisImage format with type safe checks.
wrapped() → AnalysisImageWrapper

Available on AnalysisImage, provided by the AnalysisWrapper extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited