AnalysisImageWrapper class

Available extensions

Constructors

AnalysisImageWrapper({required AnalysisImageFormat format, Uint8List? bytes, required int width, required int height, List<PlaneWrapper?>? planes, CropRectWrapper? cropRect, AnalysisRotation? rotation})

Properties

bytes ↔ Uint8List?
getter/setter pair
cropRect ↔ CropRectWrapper?
getter/setter pair
format ↔ AnalysisImageFormat
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
planes ↔ List<PlaneWrapper?>?
getter/setter pair
rotation ↔ AnalysisRotation?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ int
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
unwrap() → AnalysisImage

Available on AnalysisImageWrapper, provided by the AnalysisUnwrapper extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → AnalysisImageWrapper