Face class

A human face detected in an image.

Constructors

Face({required Rect boundingBox, required Map<FaceLandmarkType, FaceLandmark?> landmarks, required Map<FaceContourType, FaceContour?> contours, double? headEulerAngleX, double? headEulerAngleY, double? headEulerAngleZ, double? leftEyeOpenProbability, double? rightEyeOpenProbability, double? smilingProbability, int? trackingId})
Face.fromJson(Map json)
Returns an instance of Face from a given json.
factory

Properties

boundingBox → Rect
The axis-aligned bounding rectangle of the detected face.
final
contours → Map<FaceContourType, FaceContour?>
Gets the contour based on the provided FaceContourType.
final
hashCode → int
The hash code for this object.
no setterinherited
headEulerAngleX → double?
The rotation of the face about the horizontal axis of the image.
final
headEulerAngleY → double?
The rotation of the face about the vertical axis of the image.
final
headEulerAngleZ → double?
The rotation of the face about the axis pointing out of the image.
final
landmarks → Map<FaceLandmarkType, FaceLandmark?>
Gets the landmark based on the provided FaceLandmarkType.
final
leftEyeOpenProbability → double?
Probability that the face's left eye is open.
final
rightEyeOpenProbability → double?
Probability that the face's right eye is open.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
smilingProbability → double?
Probability that the face is smiling.
final
trackingId → int?
The tracking ID if the tracking is enabled.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited