FaceDetector class

A face detector that detects faces in a given InputImage.

Constructors

FaceDetector({required FaceDetectorOptions options})
Constructor to create an instance of FaceDetector.

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
Instance id.
final
options → FaceDetectorOptions
The options for the face detector.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → Future<void>
Closes the detector and releases its resources.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processImage(InputImage inputImage) → Future<List<Face>>
Processes the given image for face detection.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited