FlipInX class

key: optional widget key reference child: mandatory, widget to animate duration: how much time the animation should take delay: delay before the animation starts controller: optional/mandatory, exposes the animation controller created by Animate_do manualTrigger: boolean that indicates if you want to trigger the animation manually with the controller animate: For a State controller property, if you re-render changing it from false to true, the animation will be fired immediately onFinish: callback that returns the direction of the animation, AnimateDoDirection.forward or AnimateDoDirection.backward curve: curve for the animation from: starting point for the animation

Inheritance

Constructors

FlipInX({dynamic key, required Widget child, Duration duration = const Duration(milliseconds: 800), Duration delay = const Duration(milliseconds: 0), dynamic controller(AnimationController)?, bool manualTrigger = false, bool animate = true, dynamic onFinish(AnimateDoDirection direction)?, Curve curve = Curves.easeOut})

Properties

animate → bool
final
child → Widget
final
controller → dynamic Function(AnimationController)?
final
curve → Curve
final
delay → Duration
final
duration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
manualTrigger → bool
final
onFinish → dynamic Function(AnimateDoDirection direction)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → FlipInXState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited