Marker class

Constructors

Marker(LottieComposition _composition, String name, {required double startFrame, required double durationFrames})

Properties

durationFrames → double
final
end → double
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → double
no setter
startFrame → double
final

Methods

matchesName(String name) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited