MaterializeExtension<T> extension

Extends the Stream class with the ability to convert the onData, on Done, and onError events into Notifications that are passed into the downstream onData listener.

on

Methods

materialize() → Stream<Notification<T>>

Available on Stream<T>, provided by the MaterializeExtension extension

Converts the onData, on Done, and onError events into Notification objects that are passed into the downstream onData listener.