MediaCapture class

Constructors

MediaCapture.capturing({Exception? exception, required String filePath, VideoState? videoState})
MediaCapture.failure({Exception? exception, required String filePath})
MediaCapture.success({Exception? exception, required String filePath})

Properties

exception → Exception?
final
filePath → String
final
hashCode → int
The hash code for this object.
no setterinherited
isPicture → bool
no setter
isRecordingVideo → bool
no setter
isVideo → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → MediaCaptureStatus
final
videoState → VideoState?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited