Nv21Image class

Inheritance
Available extensions

Constructors

Nv21Image({required Uint8List bytes, required Rect cropRect, required int height, required int width, required List<ImagePlane> planes, required InputAnalysisImageFormat format, required InputAnalysisImageRotation rotation})
const
Nv21Image.from(Map<String, dynamic> map)

Properties

bytes → Uint8List
final
croppedSize → Size
Cropped size of the analysis image corresponding to what is seen on the preview.
no setteroverride
cropRect → Rect
final
format → InputAnalysisImageFormat
The format of the image.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → int
The height of the image in pixels.
finalinherited
inputImageFormat → InputImageFormat

Available on AnalysisImage, provided by the MLKitUtils extension

no setter
inputImageRotation → InputImageRotation

Available on AnalysisImage, provided by the MLKitUtils extension

no setter
planes → List<ImagePlane>
final
rotation → InputAnalysisImageRotation
The rotation of the image.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size
Full size of the analysis image.
no setterinherited
width → int
The width of the image in pixels.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toInputImage() → InputImage

Available on AnalysisImage, provided by the MLKitUtils extension

toJpeg({int quality = 100}) → Future<JpegImage>

Available on Nv21Image, provided by the Nv21Converter extension

Converts the image to a JpegImage, helping when one wants to display it or make JPEG treatment on it.
toString() → String
A string representation of this object.
inherited
when<T>({T nv21(Nv21Image image)?, T bgra8888(Bgra8888Image image)?, T jpeg(JpegImage image)?, T yuv420(Yuv420Image image)?}) → T?
Helper function to decide what to do depending on the AnalysisImage format with type safe checks.
inherited
wrapped() → AnalysisImageWrapper

Available on AnalysisImage, provided by the AnalysisWrapper extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited