PhotoCameraState class

When Camera is in Image mode

Inheritance

Constructors

PhotoCameraState({required CameraContext cameraContext, required FilePathBuilder filePathBuilder, required ExifPreferences exifPreferences})
PhotoCameraState.from(CameraContext orchestrator)
factory

Properties

analysisController → AnalysisController?
no setterinherited
cameraContext ↔ CameraContext
getter/setter pairinherited
captureMode → CaptureMode
no setteroverride
captureState → MediaCapture?
no setterinherited
captureState$ → Stream<MediaCapture?>
Use this stream to listen for capture state
no setterinherited
exifPreferences → ExifPreferences
final
filePathBuilder → FilePathBuilder
final
filter → AwesomeFilter
no setterinherited
filter$ → Stream<AwesomeFilter>
no setterinherited
filterSelectorOpened$ → Stream<bool>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saveConfig → SaveConfig?
no setterinherited
saveGpsLocation → bool
no setter
saveGpsLocation$ ↔ Stream<bool>
latefinal
sensorConfig → SensorConfig
The sensor config allows you to
no setterinherited
sensorConfig$ → Stream<SensorConfig>
no setterinherited

Methods

dispose() → void
Closes streams depending on the current state
override
focus() → dynamic
focusOnPoint({required Offset flutterPosition, required PreviewSize pixelPreviewSize, required PreviewSize flutterPreviewSize, AndroidFocusSettings? androidFocusSettings}) → Future<void>
getSensors() → Future<SensorDeviceData>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
previewSize() → Future<PreviewSize>
inherited
setFilter(AwesomeFilter newFilter) → Future<void>
inherited
setSensorType(SensorType type, String deviceId) → void
inherited
setState(CaptureMode captureMode) → void
Switch to a state between
override
shouldSaveGpsLocation(bool saveGPS) → Future<void>
switchCameraSensor({CameraAspectRatios? aspectRatio, double? zoom, FlashMode? flash, SensorType? type}) → Future<void>
Switch camera from Sensors.BACK Sensors.front All states can switch this
inherited
takePhoto() → Future<String>
Photos taken are in JPEG format. filePath must end with .jpg
textureId() → Future<int?>
inherited
toggleFilterSelector() → void
inherited
toString() → String
A string representation of this object.
inherited
when({OnVideoMode? onVideoMode, OnPhotoMode? onPhotoMode, OnPreparingCamera? onPreparingCamera, OnVideoRecordingMode? onVideoRecordingMode, OnPreviewMode? onPreviewMode, OnAnalysisOnlyMode? onAnalysisOnlyMode}) → dynamic
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited