PhotoFilterModel class

Constructors

PhotoFilterModel(String path, File imageFile, Filter filter)

Properties

filter → Filter
final
hashCode → int
The hash code for this object.
no setterinherited
imageFile → File
final
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited