SaveConfig class

Constructors

SaveConfig.photo({required FilePathBuilder pathBuilder})
You only want to take photos
SaveConfig.photoAndVideo({required FilePathBuilder photoPathBuilder, required FilePathBuilder videoPathBuilder, CaptureMode initialCaptureMode = CaptureMode.photo})
You want to be able to take both photos and videos
SaveConfig.video({required FilePathBuilder pathBuilder})
You only want to take videos

Properties

captureModes → List<CaptureMode>
final
hashCode → int
The hash code for this object.
no setterinherited
initialCaptureMode → CaptureMode
final
photoPathBuilder → FilePathBuilder?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
videoPathBuilder → FilePathBuilder?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited