TakeLastStreamTransformer<T> class

Emits only the final count values emitted by the source Stream.

Example

Stream.fromIterable([1, 2, 3, 4, 5])
  .transform(TakeLastStreamTransformer(3))
  .listen(print); // prints 3, 4, 5
Inheritance

Constructors

TakeLastStreamTransformer(int count)
Constructs a StreamTransformer which emits only the final count events from the source Stream.

Properties

count → int
The count of final items emitted when the stream completes.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<T> stream) → Stream<T>
Transforms the provided stream.
override
cast<RS, RT>() → StreamTransformer<RS, RT>
Provides a StreamTransformer<RS, RT> view of this stream transformer.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited